@@ -1,7 +1,7 @@
 package Module::Patch;
 
 our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -122,9 +122,18 @@ sub import {
             $pdata->{after_read_config}->();
         }
 
+        if ($pdata->{before_patch}) {
+            $pdata->{before_patch}->();
+        }
+
         ${"$self\::handles"} = patch_package(
             $target, $pdata->{patches},
             {force=>$force, patch_module=>ref($self) || $self});
+
+        if ($pdata->{after_patch}) {
+            $pdata->{after_patch}->();
+        }
+
     }
 }
 
@@ -134,12 +143,24 @@ sub unimport {
     my $self = shift;
 
     if ($self eq __PACKAGE__) {
-        # do nothing
+        # we are not subclassed, do nothing
     } else {
+        my $pdata = $self->patch_data or
+            die "BUG: $self: No patch data supplied";
+
+        if ($pdata->{before_unpatch}) {
+            $pdata->{before_unpatch}->();
+        }
+
         my $handles = ${"$self\::handles"};
         $log->tracef("Unpatching %s ...", [keys %$handles]);
         undef ${"$self\::handles"};
         # do we need to undef ${"$self\::config"}?, i'm thinking not really
+
+        if ($pdata->{after_unpatch}) {
+            $pdata->{after_unpatch}->();
+        }
+
     }
 }
 
@@ -255,7 +276,7 @@ Module::Patch - Patch package with a set of patches
 
 =head1 VERSION
 
-This document describes version 0.23 of Module::Patch (from Perl distribution Module-Patch), released on 2016-06-02.
+This document describes version 0.24 of Module::Patch (from Perl distribution Module-Patch), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -366,7 +387,7 @@ Must be 3 (current version).
 
 =item * patches => array
 
-Will be passed to L<Monkey::Patch::Action>'s C<patch_package()>.
+Will be passed to C<patch_package()>.
 
 =item * config => hash
 
@@ -378,6 +399,14 @@ C<default> (default value).
 
 A hook to run after patch module is imported and configuration has been read.
 
+=item * before_patch => coderef
+
+=item * after_patch => coderef
+
+=item * before_unpatch => coderef
+
+=item * after_unpatch => coderef
+
 =back
 
 =head1 FUNCTIONS
